/** DataAnalyzer.java computes the minimum, maximum, and average
 *   of an arbitrary sequence of numbers stored in a text file.
 *   Input:   double values from an input file
 *   Receive: name of input file (via main's args) 
 *   Output:  count, average, maximum, and minimum of these values
 *             to an output file
 */

import ann.util.*;             // Controller
import java.io.*;              // BufferedReader, FileReader, ...

class DataAnalyzer extends Object
{
 public static void main(String [] args)
 {
    if (args.length < 1)
      Controller.fatal("DataAnalyser.main()", 
        "\nUsage: java DataAnalyzer <inputfile> [ <outputfile> ]");

    try                                                 // try block
    {       
       BufferedReader in = new BufferedReader(          // connect to
                            new FileReader( args[0]) ); // input file
       int    count = 0;
       String valueString = "";
       double value,
              minimum = Integer.MAX_VALUE,              // start big,
              maximum = Integer.MIN_VALUE,              //  and small
              sum = 0.0;

       for (;;)                                         // input loop
       {
          valueString = in.readLine();                  // read string

          if ( valueString == null ) break;             // end-of-file
          if ( valueString.equals("") ) continue;       // empty line

          value = Double.parseDouble(valueString);     // string->double

          count++;                                     // update count,
          sum += value;                                //   sum,
          if (value < minimum) minimum = value;        //   minimum,
          if (value > maximum) maximum = value;        //   maximum
       }

       in.close();                                     // disconnect

       PrintWriter out = new PrintWriter(              // connect to
                          new BufferedWriter(          //  output file
                           new FileWriter( args[1] )));

       out.println("\nOf " + count + " values,");      // output count,

       if (count > 0)
       {
          out.println("minimum = " + minimum);          //  minimum, 
          out.println("maximum = " + maximum);          //  maximum,
          out.println("average = " + sum/count);        //  average
       }

       out.close();                                    // disconnect

       System.out.println("\nProcessing complete.\n"); // user feedback
    }

    catch (Exception anException)
    {
 	    Controller.fatal("DataAnalyzer.main()", anException.toString() );
    }
 }
}

